<a href="https://clustering-benchmarks.gagolewski.com"><img src="https://www.gagolewski.com/_static/img/clustbench.png" align="right" height="128" width="128" /></a>
# [A Framework for Benchmarking Clustering Algorithms](https://clustering-benchmarks.gagolewski.com/)

Maintained/edited/authored by [Marek Gagolewski](https://www.gagolewski.com).

This project aims to:

* **aggregate, polish, and standardise the existing clustering benchmark
    batteries** referred to across the machine learning and data mining
    literature,
* introduce **new datasets** of different dimensionalities,
    sizes, and cluster types,
* propose a **consistent methodology** for evaluating clustering algorithms.

See <https://clustering-benchmarks.gagolewski.com/> for more details.

**How to cite**:
Gagolewski M., A framework for benchmarking clustering algorithms,
*SoftwareX* **20**, 2022, 101270, <https://clustering-benchmarks.gagolewski.com>,
DOI: [10.1016/j.softx.2022.101270](https://doi.org/10.1016/j.softx.2022.101270).
